Affected by GO-2025-3528
and 5 other vulnerabilities
GO-2025-3528: containerd has an integer overflow in User ID handling in github.com/containerd/containerd
GO-2025-4100: containerd affected by a local privilege escalation via wide permissions on CRI directory in github.com/containerd/containerd
GO-2025-4108: containerd CRI server: Host memory exhaustion through Attach goroutine leak in github.com/containerd/containerd
GO-2026-5064: containerd CRI checkpoint restore CDI annotation smuggling in github.com/containerd/containerd
GO-2026-5338: containerd: CRI checkpoint import allows local image tag poisoning in github.com/containerd/containerd
GO-2026-5622: Arbitrary host CRI log file read via symlink following in CRI checkpoint restore in github.com/containerd/containerd

The highest tagged major version is
v2.
package
Version:
v1.6.29
Opens a new window with list of versions in this module.
Published: Mar 8, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 23
Opens a new window with list of known importers.
Documentation
¶
NewUnexpectedStatusErr creates an ErrUnexpectedStatus from HTTP response
type ErrUnexpectedStatus struct {
Status string
StatusCode int
Body []byte
RequestURL, RequestMethod string
}
ErrUnexpectedStatus is returned if a registry API request returned with unexpected HTTP status
Source Files
¶
Click to show internal directories.
Click to hide internal directories.